[poppler] 3 commits - qt4/src

Pino Toscano pino at kemper.freedesktop.org
Mon Sep 1 16:28:30 PDT 2008


 qt4/src/Doxyfile             |    8 +++--
 qt4/src/poppler-annotation.h |    9 ++++++
 qt4/src/poppler-form.h       |    8 +++++
 qt4/src/poppler-link.h       |   14 ++++++++--
 qt4/src/poppler-optcontent.h |   11 ++++++++
 qt4/src/poppler-qt4.h        |   59 +++++++++++++++++++++++++++++++++++++------
 6 files changed, 95 insertions(+), 14 deletions(-)

New commits:
commit 630aa133017d15ddc7bf96c79f43c5b60fa9749a
Merge: b2bc9b3... de82255...
Author: Pino Toscano <pino at kde.org>
Date:   Tue Sep 2 01:25:55 2008 +0200

    Merge branch 'master' of ssh://pino@git.freedesktop.org/git/poppler/poppler

commit b2bc9b3f59ef8e5fea18f0bc91b71fc9eb9a4157
Author: Pino Toscano <pino at kde.org>
Date:   Tue Sep 2 01:24:39 2008 +0200

    [Qt4] small apidox improvements
    
    mostly the start of the \since marker addition, plus few other
    documentation addition/improvements

diff --git a/qt4/src/poppler-annotation.h b/qt4/src/poppler-annotation.h
index 9609dae..9b8b54d 100644
--- a/qt4/src/poppler-annotation.h
+++ b/qt4/src/poppler-annotation.h
@@ -178,6 +178,9 @@ class POPPLER_QT4_EXPORT Annotation
     const QLinkedList< Revision >& revisions() const;
 
     // methods: query annotation's type for runtime type identification
+    /**
+     * The type of the annotation.
+     */
     virtual SubType subType() const = 0;
 
     // methods: storage/retrieval from xml nodes
@@ -538,6 +541,8 @@ class POPPLER_QT4_EXPORT CaretAnnotation : public Annotation
  * \short File attachment annotation.
  *
  * The file attachment annotation represents a file embedded in the document.
+ *
+ * \since 0.10
  */
 class POPPLER_QT4_EXPORT FileAttachmentAnnotation : public Annotation
 {
@@ -563,6 +568,8 @@ class POPPLER_QT4_EXPORT FileAttachmentAnnotation : public Annotation
  * \short Sound annotation.
  *
  * The sound annotation represents a sound to be played when activated.
+ *
+ * \since 0.10
  */
 class POPPLER_QT4_EXPORT SoundAnnotation : public Annotation
 {
@@ -588,6 +595,8 @@ class POPPLER_QT4_EXPORT SoundAnnotation : public Annotation
  * \short Movie annotation.
  *
  * The movie annotation represents a movie to be played when activated.
+ *
+ * \since 0.10
  */
 class POPPLER_QT4_EXPORT MovieAnnotation : public Annotation
 {
diff --git a/qt4/src/poppler-form.h b/qt4/src/poppler-form.h
index 7307fd0..5b4b4f8 100644
--- a/qt4/src/poppler-form.h
+++ b/qt4/src/poppler-form.h
@@ -37,6 +37,8 @@ namespace Poppler {
     class FormFieldData;
     /**
       The base class representing a form field.
+
+      \since 0.6
      */
     class POPPLER_QT4_EXPORT FormField {
     public:
@@ -110,6 +112,8 @@ namespace Poppler {
 
     /**
       A form field that represents a "button".
+
+      \since 0.8
      */
     class POPPLER_QT4_EXPORT FormFieldButton : public FormField {
     public:
@@ -165,6 +169,8 @@ namespace Poppler {
 
     /**
       A form field that represents a text input.
+
+      \since 0.6
      */
     class POPPLER_QT4_EXPORT FormFieldText : public FormField {
     public:
@@ -236,6 +242,8 @@ namespace Poppler {
 
     /**
       A form field that represents a choice field.
+
+      \since 0.6
      */
     class POPPLER_QT4_EXPORT FormFieldChoice : public FormField {
     public:
diff --git a/qt4/src/poppler-optcontent.h b/qt4/src/poppler-optcontent.h
index 99471a0..3f47853 100644
--- a/qt4/src/poppler-optcontent.h
+++ b/qt4/src/poppler-optcontent.h
@@ -32,6 +32,17 @@ namespace Poppler
   class Document;
   class OptContentModelPrivate;
 
+  /**
+   * \brief Model for optional content
+   *
+   * OptContentModel is an item model representing the optional content items
+   * that can be found in PDF documents.
+   *
+   * The model offers a mostly read-only display of the data, allowing to
+   * enable/disable some contents setting the Qt::CheckStateRole data role.
+   *
+   * \since 0.8
+   */
   class POPPLER_QT4_EXPORT OptContentModel : public QAbstractItemModel
   {
     friend class Document;
diff --git a/qt4/src/Doxyfile b/qt4/src/Doxyfile
index 2292600..d4bf796 100644
--- a/qt4/src/Doxyfile
+++ b/qt4/src/Doxyfile
@@ -488,6 +488,7 @@ INPUT                  = Mainpage.dox \
                          poppler-form.h \
                          poppler-link.h \
                          poppler-qt4.h \
+                         poppler-optcontent.h \
                          poppler-page-transition.h
 
 # This tag can be used to specify the character encoding of the source files that 
@@ -1031,13 +1032,13 @@ ENABLE_PREPROCESSING   = YES
 # compilation will be performed. Macro expansion can be done in a controlled 
 # way by setting EXPAND_ONLY_PREDEF to YES.
 
-MACRO_EXPANSION        = NO
+MACRO_EXPANSION        = YES
 
 # If the EXPAND_ONLY_PREDEF and MACRO_EXPANSION tags are both set to YES 
 # then the macro expansion is limited to the macros specified with the 
 # PREDEFINED and EXPAND_AS_DEFINED tags.
 
-EXPAND_ONLY_PREDEF     = NO
+EXPAND_ONLY_PREDEF     = YES
 
 # If the SEARCH_INCLUDES tag is set to YES (the default) the includes files 
 # in the INCLUDE_PATH (see below) will be search if a #include is found.
@@ -1065,7 +1066,8 @@ INCLUDE_FILE_PATTERNS  =
 # undefined via #undef or recursively expanded use the := operator 
 # instead of the = operator.
 
-PREDEFINED             = 
+PREDEFINED             = \
+                         POPPLER_QT4_EXPORT=""
 
 # If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then 
 # this tag can be used to specify a list of macro names that should be expanded. 


More information about the poppler mailing list
diff --git a/qt4/src/poppler-link.h b/qt4/src/poppler-link.h
index c088ea8..fb973fa 100644
--- a/qt4/src/poppler-link.h
+++ b/qt4/src/poppler-link.h
@@ -127,7 +127,7 @@ class POPPLER_QT4_EXPORT Link
 		    Action,
 		    Sound,    ///< A link representing a sound to be played
 		    Movie,
-		    JavaScript    ///< A JavaScript code to be interpreted
+		    JavaScript    ///< A JavaScript code to be interpreted \since 0.10
 		};
 
 		/**
@@ -296,7 +296,11 @@ class POPPLER_QT4_EXPORT LinkAction : public Link
 		Q_DISABLE_COPY( LinkAction )
 };
 
 /** Sound: a sound to be played **/
 class POPPLER_QT4_EXPORT LinkSound : public Link
 {
 	public:
@@ -345,7 +349,11 @@ class POPPLER_QT4_EXPORT LinkSound : public Link
 		Q_DISABLE_COPY( LinkSound )
 };
 
 /** JavaScript: a JavaScript code to be interpreted. **/
 class POPPLER_QT4_EXPORT LinkJavaScript : public Link
 {
 	public:
@@ -296,7 +296,11 @@ class POPPLER_QT4_EXPORT LinkAction : public Link
 };
 
-/** Sound: a sound to be played **/
+/**
+ * Sound: a sound to be played.
+ *
+ * \since 0.6
+ */
 class POPPLER_QT4_EXPORT LinkSound : public Link
 {
@@ -345,7 +349,11 @@ class POPPLER_QT4_EXPORT LinkSound : public Link
 };
 
-/** JavaScript: a JavaScript code to be interpreted. **/
+/**
+ * JavaScript: a JavaScript code to be interpreted.
+ *
+ * \since 0.10
+ */
 class POPPLER_QT4_EXPORT LinkJavaScript : public Link
 {
diff --git a/qt4/src/poppler-qt4.h b/qt4/src/poppler-qt4.h
index d23a024..b677b4d 100644
--- a/qt4/src/poppler-qt4.h
+++ b/qt4/src/poppler-qt4.h
@@ -86,6 +86,8 @@ namespace Poppler {
       /**
 	  Returns the position of the text, in point, i.e., 1/72 of
 	 an inch
+
+	 \since 0.8
       */
       QRectF boundingBox() const;
 
@@ -269,6 +271,8 @@ namespace Poppler {
 
 	/**
 	   The MIME type of the file, if known.
+	
+	   \since 0.8
 	*/
 	QString mimeType() const;
 
@@ -355,6 +359,8 @@ namespace Poppler {
 	   rather unexpected results.
 
 	   \returns a QImage of the page, or a null image on failure.
+
+	   \since 0.6
         */
 	QImage renderToImage(double xres=72.0, double yres=72.0, int x=-1, int y=-1, int w=-1, int h=-1, Rotation rotate = Rotate0) const;
 
@@ -424,15 +430,18 @@ namespace Poppler {
 	  Returns the transition of this page
 
 	  \returns a pointer to a PageTransition structure that
-	  defines how transition to this page shall be performed. The
-	  PageTransition structure is owned by this page, and will
+	  defines how transition to this page shall be performed.
+
+	  \note The PageTransition structure is owned by this page, and will
 	  automatically be destroyed when this page class is
 	  destroyed.
 	**/
 	PageTransition *transition() const;
 	
 	/**
-	  Gets the page action specified, or NULL if there is no action
+	  Gets the page action specified, or NULL if there is no action.
+
+	  \since 0.6
 	**/
 	Link *action( PageAction act ) const;
 	
@@ -468,6 +477,8 @@ namespace Poppler {
 
 	/**
 	 Returns the form fields on the page
+
+	 \since 0.6
 	*/
 	QList<FormField*> formFields() const;
 
@@ -475,11 +486,15 @@ namespace Poppler {
 	 Returns the page duration. That is the time, in seconds, that the page
 	 should be displayed before the presentation automatically advances to the next page.
 	 Returns < 0 if duration is not set.
+
+	 \since 0.6
 	*/
 	double duration() const;
 	
 	/**
 	   Returns the label of the page, or a null string is the page has no label.
+
+	 \since 0.6
 	**/
 	QString label() const;
 	
@@ -665,7 +680,6 @@ QDateTime modified = m_doc->date("ModDate");
 	   - ModDate: the date of the last change in the document
 
 	   \param data the type of date that is required
-
 	*/
 	QDateTime date( const QString & data ) const;
 
@@ -800,6 +814,8 @@ QString subject = m_doc->info("Subject");
 
 	/**
 	   The font data if the font is an embedded one.
+
+	   \since 0.10
 	*/
 	QByteArray fontData(const FontInfo &font) const;
 
@@ -817,8 +833,9 @@ QString subject = m_doc->info("Subject");
 	bool hasEmbeddedFiles() const;
 	
 	/**
-	  Gets the TOC of the Document, it is application responsabiliy to delete
-	  it when no longer needed
+	  Gets the table of contents (TOC) of the Document.
+	
+	  The caller is responsable for the returned object.
 	
 	  In the tree the tag name is the 'screen' name of the entry. A tag can have
 	  attributes. Here follows the list of tag attributes with meaning:
@@ -828,7 +845,7 @@ QString subject = m_doc->info("Subject");
 	  - ExternalFileName: A link to a external filename
 	  - Open: A bool value that tells whether the subbranch of the item is open or not
 	
-	  Returns NULL if the Document does not have TOC
+	  \returns the TOC, or NULL if the Document does not have one
 	*/
 	QDomDocument *toc() const;
 	
@@ -885,6 +902,8 @@ QString subject = m_doc->info("Subject");
 	  Gets a new PS converter for this document.
 
 	  The caller gets the ownership of the returned converter.
+
+	  \since 0.6
 	 */
 	PSConverter *psConverter() const;
 	
@@ -892,11 +911,15 @@ QString subject = m_doc->info("Subject");
 	  Gets a new PDF converter for this document.
 
 	  The caller gets the ownership of the returned converter.
+
+	  \since 0.8
 	 */
 	PDFConverter *pdfConverter() const;
 	
 	/**
 	  Gets the metadata stream contents
+
+	  \since 0.6
 	*/
 	QString metadata() const;
 
@@ -909,6 +932,8 @@ QString subject = m_doc->info("Subject");
 	   applications, but it can be used for a range of things,
 	   such as not including some content in printing, and
 	   displaying content in the appropriate language.
+
+	   \since 0.8
 	*/
 	bool hasOptionalContent() const;
 
@@ -916,6 +941,8 @@ QString subject = m_doc->info("Subject");
 	   Itemviews model for optional content.
 
 	   The model is owned by the document.
+
+	   \since 0.8
 	*/
 	OptContentModel *optionalContentModel();
 
@@ -924,6 +951,8 @@ QString subject = m_doc->info("Subject");
 
 	   Returns the list of document level JavaScript scripts to be always
 	   executed before any other script.
+
+	   \since 0.10
 	*/
 	QStringList scripts() const;
 
@@ -947,6 +976,8 @@ QString subject = m_doc->info("Subject");
        \brief Base converter.
 
        This is the base class for the converters.
+
+       \since 0.8
     */
     class POPPLER_QT4_EXPORT BaseConverter
     {
@@ -960,7 +991,11 @@ QString subject = m_doc->info("Subject");
             /** Sets the output file name. You must set this or the output device. */
             void setOutputFileName(const QString &outputFileName);
 
             /** Sets the output device. You must set this or the output file name. */
             void setOutputDevice(QIODevice *device);
 
             /**
@@ -994,6 +1029,8 @@ dummy.setPageSize(myPageSize);
 width = dummy.width();
 height = dummy.height();
        \endcode
+
+       \since 0.6
     */
     class POPPLER_QT4_EXPORT PSConverter : public BaseConverter
     {
@@ -1080,6 +1117,8 @@ height = dummy.height();
 
     /**
        Converts a PDF to PDF (thus saves a copy of the document).
+
+       \since 0.8
     */
     class POPPLER_QT4_EXPORT PDFConverter : public BaseConverter
     {
@@ -1128,6 +1167,8 @@ height = dummy.height();
 	A sound can be either External (in that case should be loaded the file
        whose url is represented by url() ), or Embedded, and the player has to
        play the data contained in data().
+
+       \since 0.6
     */
     class POPPLER_QT4_EXPORT SoundObject {
     public:
@@ -1199,6 +1240,8 @@ height = dummy.height();
     class MovieData;
     /**
        Container class for a movie object in a PDF document.
+
+       \since 0.10
     */
     class POPPLER_QT4_EXPORT MovieObject {
     friend class Page;
@@ -960,7 +991,11 @@ QString subject = m_doc->info("Subject");
             void setOutputFileName(const QString &outputFileName);
 
-            /** Sets the output device. You must set this or the output file name. */
+            /**
+             * Sets the output device. You must set this or the output file name.
+             *
+             * \since 0.8
+             */
             void setOutputDevice(QIODevice *device);
 
commit 6bc4881477ea15d70d420e57b5663052f2f9df76
Author: Pino Toscano <pino at kde.org>
Date:   Tue Sep 2 00:47:56 2008 +0200

    expand the macros, extract poppler-optcontent.h
    
    enable the macro expansion and define POPPLER_QT4_EXPORT to be empty, so
    we don't have it in the apidox
